@@ -1,4 +1,4 @@
-from django.db.models.fields import FieldDoesNotExist
+from django.core.exceptions import FieldDoesNotExist
 
 
 def get_model_field_names(model):
